@@ -1,4 +1,5 @@
 
+import pathlib
 import re
 import shutil
 import subprocess
@@ -9,6 +10,7 @@ import abstracts
 
 from aio.core import subprocess as _subprocess
 from aio.core.functional import async_property
+from aio.run import checker
 
 from envoy.code.check import abstract, typing
 
@@ -71,7 +73,7 @@ class Shellcheck(_subprocess.ASubprocessHandler):
                     str,
                     ShellcheckErrorDict]]) -> typing.ProblemDict:
         return {
-            k: self._render_file_errors(k, v)
+            k: checker.Problems(errors=self._render_file_errors(k, v))
             for k, v
             in errors}
 
@@ -184,10 +186,11 @@ class AShellcheckCheck(
         return "|".join(SHEBANG_RE)
 
     @cached_property
-    def shellcheck_command(self) -> str:
+    def shellcheck_command(self) -> str | pathlib.Path:
         """Shellcheck command, should be available in the running system."""
-        command = shutil.which("shellcheck")
-        if command:
+        if "shellcheck" in self.binaries:
+            return pathlib.Path(self.binaries["shellcheck"]).absolute()
+        if command := shutil.which("shellcheck"):
             return command
         raise _subprocess.exceptions.OSCommandError(
             "Unable to find shellcheck command")
