@@ -1,10 +1,12 @@
 
-from typing import Dict, List, Tuple, TypedDict
+from typing import Dict, List, Optional, Tuple, TypedDict
+
+from aio.run import checker
 
 
-ProblemDict = Dict[str, List[str]]
+ProblemDict = Dict[str, checker.interface.IProblems]
 
-YapfProblemTuple = Tuple[str, List[str]]
+YapfProblemTuple = Tuple[str, checker.interface.IProblems]
 YapfResultTuple = Tuple[str, str, bool]
 YapfCheckResultTuple = Tuple[str, YapfResultTuple]
 
@@ -17,22 +19,31 @@ class BaseExtensionMetadataDict(TypedDict):
 
 class ExtensionMetadataDict(BaseExtensionMetadataDict, total=False):
     undocumented: bool
+    type_urls: List[str]
 
 
 ExtensionsMetadataDict = Dict[str, ExtensionMetadataDict]
-
-
 ExtensionsSchemaCategoriesList = List[str]
 ExtensionsSchemaBuiltinList = List[str]
 ExtensionsSchemaSecurityPosturesList = List[str]
 ExtensionsSchemaStatusValuesList = List[str]
 
 
+class ExtensionSecurityPostureMetadataDict(TypedDict):
+    name: str
+    description: str
+
+
+class ExtensionStatusMetadataDict(TypedDict):
+    name: str
+    description: Optional[str]
+
+
 class ExtensionsSchemaDict(TypedDict):
     builtin: ExtensionsSchemaBuiltinList
-    security_postures: ExtensionsSchemaSecurityPosturesList
+    security_postures: List[ExtensionSecurityPostureMetadataDict]
     categories: ExtensionsSchemaCategoriesList
-    status_values: ExtensionsSchemaStatusValuesList
+    status_values: List[ExtensionStatusMetadataDict]
 
 
 ConfiguredExtensionsDict = Dict[str, str]
